﻿using System;
using System.Linq;
using System.Runtime.Serialization;
using System.ServiceModel;
using System.ServiceModel.Activation;
using System.Collections.ObjectModel; 
using AddressBookData;
using System.Collections.Generic;

namespace AddressBookSilverlightApp.Web
{
    [ServiceContract(Namespace = "")]
    [AspNetCompatibilityRequirements(RequirementsMode = AspNetCompatibilityRequirementsMode.Allowed)]
    public class AddressBookService
    {
        [OperationContract]
        public List<Entry> GetEntries()
        {
            using (var container = new AddressBookContainer())
            {
                return container.Entries.ToList<Entry>();
            }
        }

        [OperationContract]
        public Entry GetEntry(string name)
        {
            using (var container = new AddressBookContainer())
            {
                return container.Entries.Where(e => e.Name == name).First();
            }
        }

        [OperationContract]
        public bool UpdateEntry(Entry entry)
        {
            using (var container = new AddressBookContainer())
            {
                try
                {
                    container.Entries.ApplyChanges<Entry>(entry);
                    container.SaveChanges();
                    return true;
                }
                catch (System.Data.OptimisticConcurrencyException ex)
                {
                    return false;
                }
            }
        }

        [OperationContract]
        public bool UpdateEntries(IEnumerable<Entry> entries)
        {
            using (var container = new AddressBookContainer())
            {
                try
                {
                    foreach (var entry in entries)
                    {
                        container.Entries.ApplyChanges(entry);
                    }

                    container.SaveChanges();
                    return true;
                }
                catch (System.Data.OptimisticConcurrencyException ex)
                {
                    return false;
                }
            }
        }
    
    }
}
